Coverage for appr/models/kv/redis/channel.py: 100%

# Coverage for appr/models/kv/redis/channel.py : 100%

## 5 statements 5 run 0 missing 0 excluded

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 2 3 4 5 6 7 8 | from __future__ import absolute_import, division, print_function from appr.models.kv.channel_kv_base import ChannelKvBase from appr.models.kv.redis.models_index import ModelsIndexRedis class Channel(ChannelKvBase): index_class = ModelsIndexRedis